@@ -8,6 +8,7 @@ import json
 import unittest
 
 from imap_cli import config
+from imap_cli import const
 
 
 class ConfigTest(unittest.TestCase):
@@ -27,6 +28,24 @@ class ConfigTest(unittest.TestCase):
         for key, value in config.DEFAULT_CONFIG.items():
             assert self.conf[key] == value
 
+    def test_config_file_from_default_config_file(self):
+        const.DEFAULT_CONFIG_FILE = 'config-example.ini'
+
+        self.conf = config.new_context_from_file()
+
+        if self.conf is not None:
+            for key, value in config.DEFAULT_CONFIG.items():
+                assert self.conf[key] == value
+
+    def test_config_file_from_non_existing_file(self):
+        const.DEFAULT_CONFIG_FILE = 'config-imaginary-file.ini'
+
+        self.conf = config.new_context_from_file()
+
+        if self.conf is not None:
+            for key, value in config.DEFAULT_CONFIG.items():
+                assert self.conf[key] == value
+
     def test_config_file_from_json(self):
         json_config = ''.join([
             '{"username": "username", "hostname": "imap.example.org", "format_list": "\\nID:         ',
