@@ -6,6 +6,7 @@
 
 import datetime
 import imaplib
+import sys
 import unittest
 
 from imap_cli import search
@@ -18,13 +19,11 @@ class SearchTests(unittest.TestCase):
 
     def test_basic_search(self):
         self.imap_account = imaplib.IMAP4_SSL()
-        self.imap_account.login()
 
         assert search.create_search_criterion() == ['ALL']
 
     def test_create_search_criteria_by_date(self):
         self.imap_account = imaplib.IMAP4_SSL()
-        self.imap_account.login()
 
         date = datetime.datetime(1989, 1, 3)
         search_criterion = search.create_search_criterion(date=date)
@@ -50,7 +49,6 @@ class SearchTests(unittest.TestCase):
 
     def test_create_search_criterion_by_mail_address(self):
         self.imap_account = imaplib.IMAP4_SSL()
-        self.imap_account.login()
 
         mail_address = 'user@example.tld'
         search_criterion = search.create_search_criterion(address=mail_address)
@@ -67,7 +65,6 @@ class SearchTests(unittest.TestCase):
 
     def test_create_search_criteria_by_size(self):
         self.imap_account = imaplib.IMAP4_SSL()
-        self.imap_account.login()
 
         size = 3141592
         search_criterion = search.create_search_criterion(size=size)
@@ -84,7 +81,6 @@ class SearchTests(unittest.TestCase):
 
     def test_create_search_criterion_by_subject(self):
         self.imap_account = imaplib.IMAP4_SSL()
-        self.imap_account.login()
 
         subject = 'subject searched'
         search_criterion = search.create_search_criterion(subject=subject)
@@ -95,7 +91,6 @@ class SearchTests(unittest.TestCase):
 
     def test_create_search_criteria_by_tag(self):
         self.imap_account = imaplib.IMAP4_SSL()
-        self.imap_account.login()
 
         tags = ['seen']
         search_criterion = search.create_search_criterion(tags=tags)
@@ -111,7 +106,6 @@ class SearchTests(unittest.TestCase):
 
     def test_create_search_criteria_by_text(self):
         self.imap_account = imaplib.IMAP4_SSL()
-        self.imap_account.login()
 
         text = 'CONTENT'
         search_criterion = search.create_search_criterion(text=text)
@@ -119,6 +113,45 @@ class SearchTests(unittest.TestCase):
 
     def test_execute_simple_search(self):
         self.imap_account = imaplib.IMAP4_SSL()
-        self.imap_account.login()
 
         assert search.fetch_uids(self.imap_account) == ['1']
+
+    def test_fetch_mails_info(self):
+        self.imap_account = imaplib.IMAP4_SSL()
+
+        reference_mails_info = [{
+            'from': u'exampleFrom <example@from.org>',
+            'to': u'exampleTo <example@to.org>',
+            'subject': u'Mocking IMAP Protocols',
+            'id': [u'1'],
+            'flags': [u'\\Seen', u'NonJunk'],
+            'date': u'Tue, 03 Jan 1989 09:42:34 +0200',
+            'uid': [u'1'],
+        }]
+        assert list(search.fetch_mails_info(self.imap_account)) == reference_mails_info
+
+    def test_fetch_uids(self):
+        self.imap_account = imaplib.IMAP4_SSL()
+
+        assert list(search.fetch_uids(self.imap_account)) == ['1']
+
+    def test_fetch_threads(self):
+        self.imap_account = imaplib.IMAP4_SSL()
+
+        assert list(search.fetch_threads(self.imap_account)) == [[[1], [2]], [3, 4]]
+
+    def test_search_cli_tools(self):
+        sys.argv = ['imap-cli-search', '-c', 'config-example.ini']
+        assert search.main() == 0
+
+        sys.argv = ['imap-cli-search --thread', '-c', 'config-example.ini']
+        assert search.main() == 0
+
+        sys.argv = ['imap-cli-search -t testTag -T testText', '-c', 'config-example.ini']
+        assert search.main() == 0
+
+        sys.argv = ['imap-cli-search', '-a', 'user@exemple.org']
+        assert search.main() == 0
+
+        sys.argv = ['imap-cli-search', '-f', '{from}']
+        assert search.main() == 0
